==> drake_7.0.0.tar.gz: drake/R/utils-defunct.R <==
drake_defunct <- function(...) {
  .Defunct(
    new = "",
    package = "drake",
    msg = paste0("function ", match.call()[[1]], "() in drake is defunct.")
  )
}

# nocov start

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
analyses <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
as_drake_filename <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
as_file <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
backend <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
build_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
check <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
config <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
dataframes_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
default_system2_args <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
deprecate_wildcard <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
doc_of_function_call <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
evaluate <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
example_drake <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
examples_drake <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
expand <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
gather <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
find_knitr_doc <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
is_function_call <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
load_basic_example <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
parallel_stages <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
plan <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
plan_drake <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
plot_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
rate_limiting_times <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
read_config <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
read_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
read_drake_meta <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
read_plan <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
render_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
session <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
summaries <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
workflow <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
workplan <- drake_defunct

# nocov end

==> drake_7.1.0.tar.gz: drake/R/utils-defunct.R <==
drake_defunct <- function(...) {
  .Defunct(
    new = "",
    package = "drake",
    msg = paste0("function ", match.call()[[1]], "() in drake is defunct.")
  )
}

# nocov start

#' @title Defunct function.
#' @description The `from_plan()` function is now defunct
#'   in order to reduce the demands on memory usage.
#' @details 2019-03-28
#' @export
#' @keywords internal
#' @seealso [drake_envir()]
#' @param column Character, name of a column in your `drake` plan.
from_plan <- function(column) {
  .Defunct(
    new = "",
    package = "drake",
    msg = c(
      "Function from_plan() in drake is now defunct ",
      "in order to reduce memory usage."
    )
  )
  NULL
}

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
analyses <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
as_drake_filename <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
as_file <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
backend <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
build_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
check <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
config <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
dataframes_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
default_system2_args <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
deprecate_wildcard <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
doc_of_function_call <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
evaluate <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
example_drake <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
examples_drake <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
expand <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
gather <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
find_knitr_doc <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
is_function_call <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
load_basic_example <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
parallel_stages <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
plan <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
plan_drake <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
plot_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
rate_limiting_times <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
read_config <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
read_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
read_drake_meta <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
read_plan <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
render_graph <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
session <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
summaries <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
workflow <- drake_defunct

#' @title Defunct function
#' @description 2019-02-15
#' @export
#' @keywords internal
#' @param ... Arguments
workplan <- drake_defunct

# nocov end
